"""autopop: Auto Populate GDoc tables using LLMs."""

__version__ = '0.9'

from .aws_util import get_sm_client, get_creds, get_secret_key
from .aspect_factory import AspectFactory, DDBPromptWrapper
from .google_util_wrapper import GoogleUtilWrapper
from .ddb_util_wrapper import DDBUtilWrapper
from .llm_util import initialize_llm

__all__ = [
    'get_sm_client',
    'get_creds',
    'get_secret_key',
    'AspectFactory',
    'DDBPromptWrapper',
    'GoogleUtilWrapper',
    'DDBUtilWrapper',
    'initialize_llm'
]



from setuptools import setup, find_packages

setup(
    name='autopop',
    version='0.9',
    packages=find_packages(),
    install_requires=[
        'requests',
        'selenium',
        'openai',
        'anthropic', 
        'paper-qa',
        'langchain',
        'importlib',
        'boto3'
    ],
    author='David Schwartz',
    author_email='david.schwartz@devfactory.com',
    description='Auto Populate GDoc tables using LLMs.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/yourusername/yourrepository',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)
